==> mercadolibre-sdk-0.0.2.tar.gz: mercadolibre-sdk-0.0.2/README.md <==
# Mercado Libre - SDK (unofficial)

## Configuration for using in  backend services

1. Install [ngrok](https://ngrok.com/) for localhost authorization
```shell
 curl -s https://ngrok-agent.s3.amazonaws.com/ngrok.asc | sudo tee /etc/apt/trusted.gpg.d/ngrok.asc >/dev/null && echo "deb https://ngrok-agent.s3.amazonaws.com buster main" | sudo tee /etc/apt/sources.list.d/ngrok.list && sudo apt update && sudo apt install ngrok
```

2. Follow the instructions in [ngrok page](https://dashboard.ngrok.com/get-started/your-authtoken)

3. Create a free domain in [ngrok domains page](https://dashboard.ngrok.com/cloud-edge/domains)

4. Set the environment variables
```shell
MERCADOLIBRE_CLIENT_ID
MERCADOLIBRE_CLIENT_SECRET
MERCADOLIBRE_REDIRECT_URI={this should be your ngrok domain url}
```

5. If you want to save your tokens in a Redis database set
```shell
MERCADOLIBRE_REDIS_HOST
MERCADOLIBRE_REDIS_PORT
```

6. Run in your terminal
```shell
mercadolibre.authorize
```

## Configuration for using in frontend services
Set the environment variables
```shell
MERCADOLIBRE_CLIENT_ID
MERCADOLIBRE_CLIENT_SECRET
MERCADOLIBRE_REDIRECT_URI={your backend url}
```

## Licence
MIT License

Copyright (c) 2023 Mercado Radar

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

---

Mercado Libre and its trademarks are the property of MercadoLibre, Inc.
Mercado Radar is not affiliated, endorsed, or sponsored by MercadoLibre, Inc.
This client is an independent, unofficial software developed by Mercado Radar.
All copyrights and trademarks mentioned here are the property of their respective owners.

==> mercadolibre-sdk-0.0.9.tar.gz: mercadolibre-sdk-0.0.9/README.md <==
# Mercado Libre - SDK (unofficial)

## Configuration for using in  backend services

1. Install [ngrok](https://ngrok.com/) for localhost authorization

```shell
 curl -s https://ngrok-agent.s3.amazonaws.com/ngrok.asc | sudo tee /etc/apt/trusted.gpg.d/ngrok.asc >/dev/null && echo "deb https://ngrok-agent.s3.amazonaws.com buster main" | sudo tee /etc/apt/sources.list.d/ngrok.list && sudo apt update && sudo apt install ngrok
```

2. Follow the instructions in [ngrok page](https://dashboard.ngrok.com/get-started/your-authtoken)

3. Create a free domain in [ngrok domains page](https://dashboard.ngrok.com/cloud-edge/domains)

4. Set the environment variables

```shell
MERCADOLIBRE_CLIENT_ID
MERCADOLIBRE_CLIENT_SECRET
MERCADOLIBRE_REDIRECT_URI={this should be your ngrok domain url}
```

5. If you want to save your tokens in a Redis database set

```shell
MERCADOLIBRE_REDIS_HOST
MERCADOLIBRE_REDIS_PORT
```

6. Run in your terminal

```shell
mercadolibre.authorize
```

All envs variables can be defined in a .env file in your root folder

## Configuration for using with frontend services

Set the environment variables

```shell
MERCADOLIBRE_CLIENT_ID
MERCADOLIBRE_CLIENT_SECRET
MERCADOLIBRE_REDIRECT_URI={your backend url that handles login}
```

All envs variables can be defined in a .env file in your root folder

## Licence

MIT License

Copyright (c) 2023 Mercado Radar

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

---

Mercado Libre and its trademarks are the property of MercadoLibre, Inc.
Mercado Radar is not affiliated, endorsed, or sponsored by MercadoLibre, Inc.
This client is an independent, unofficial software developed by Mercado Radar.
All copyrights and trademarks mentioned here are the property of their respective owners.
